#!/bin/bash
# (C) Copyright 2007-2013 Hewlett Packard Development Company, L.P.
# Version A.12.00.00

################################################################################
# hatomcat.sh: HA Tomcat Toolkit Main Script
################################################################################
# This script contains a list of internal-use variables and functions that 
# support start/stop of an Tomcat instance and its monitor process.  
#
# Note: Do not modify this script
#
# Parameters:
#    Action:    either "start" or "stop" or "monitor"
#  
# Exit Code:
#    1 - when a failure occurs during the "start" or "stop" process.
#    0 - normal exit.
#
# REVISION HISTORY:
#     Version      mm/dd/yyyy   Changes
#     A.03.00      07/17/2006   1) Added -s /bin/bash to su command
#
#     A.04.00                   1) Made Modular compliant
#
#     A.04.02.01   04/30/2012   1) Added check for the attribute
#                                  MONITOR_INTERVAL.
#                               2) Regular expression on netstat -ln
#                                  command result is modified.
#     A.04.02.02   10/19/2012   1) Updated the version to A.04.02.02
#                               2) Changed the default RETRY_TIMES to 0
#     A.12.00.00   12/04/2013   1) Removed toolkit maintenance mode support
#                               2) Removed Legacy style packaging support
#                               3) Removed user restriction of only root/www user 
################################################################################

#include the PATHs 
HOSTNAME=`hostname`
PATH=/usr/bin:/usr/sbin:/usr/lbin:/bin
MAX_WAIT_TIME=15

#Check whether the CATALINA_HOME is valid 
if [ ! -f "${CATALINA_HOME}/bin/catalina.sh" ] ; then
    echo "$(date '+%b %e %T') -Node \"$HOSTNAME\" ERROR: Invalid parameter, CATALINA_HOME"
    exit 1
fi

# Assigning default value 30 to MONITOR_INTERVAL.
if [ -z $MONITOR_INTERVAL ]; then
    MONITOR_INTERVAL=30
fi

CATALINA_BASE=${CATALINA_BASE:=$CATALINA_HOME}


# Make sure that RETRY_TIMES has been defined otherwise, use the toolkit 
# default
RETRY_TIMES=${RETRY_TIMES:=0}

# This function starts the Tomcat java daemon
#
function start_server
{
	typeset -i i=0;
    echo "$(date '+%b %e %T') - Node \"$HOSTNAME\": Starting Tomcat daemons."
    su -s /bin/bash ${TOMCAT_USER} << EOF 
export CATALINA_HOME=${CATALINA_HOME} 
export CATALINA_BASE=${CATALINA_BASE} 
export JAVA_HOME=${JAVA_HOME} 
${CATALINA_HOME}/bin/startup.sh
EOF
    ret_value=$?
    check_return $ret_value 1
	ret_value=1
	while [[ i -lt $MAX_WAIT_TIME ]]; do
		sleep 1
                #Check the port number is opened for listening.	
		netstat -ln |grep -q "\:${MONITOR_PORT}[ ]\+.\+[ ]\+LISTEN"
		if [ $? -eq 0 ]; then
			ret_value=0
			break;
		else
		   (( i = i + 1 ))
		fi
	done
	check_return $ret_value 1

}


# This function kills running tomcat daemons of this Tomcat instance
#
function stop_server
{
    echo "$(date '+%b %e %T') - Node \"$HOSTNAME\": Stopping Tomcat daemons"
    su -s /bin/bash ${TOMCAT_USER} << EOF 
export CATALINA_HOME=${CATALINA_HOME} 
export CATALINA_BASE=${CATALINA_BASE} 
export JAVA_HOME=${JAVA_HOME} 
${CATALINA_HOME}/bin/shutdown.sh
EOF
    check_return $? 4
    return 0
}


# Check return value of functions and exit.
# Parameter:    $1: exit code of a previous command
#               $2: function ID
function check_return
{
    if (( $1 != 0 ))
    then
    case $2 in
        1)
                echo "$(date '+%b %e %T') -Node \"$HOSTNAME\" ERROR: Function start_server: Failed to start Tomcat daemons."
                exit 1
                ;;
        2)
                echo "$(date '+%b %e %T') -Node \"$HOSTNAME\" ERROR: Function start_monitor_service: Failed to start monitor process."
                stop_server
                exit 1
                ;;
        3)
                echo "$(date '+%b %e %T') -Node \"$HOSTNAME\" ERROR: Function halt_monitor_service: Failed to halt monitor process."
                exit_code=1
                ;;
        4)
                echo "$(date '+%b %e %T') -Node \"$HOSTNAME\" ERROR: Function stop_server: Failed to stop Tomcat daemons"
                exit 1
                ;;
    esac
    fi
}


# Script Start 

exit_code=0

# Test to see if we are being called to start the package, or stop the package.
case $1 in
start)
    start_server
    ;;
monitor)
    echo "$(date '+%b %e %T') - Node \"$(hostname)\": Starting hatomcat.mon service"
    # Monitor script parameter list:
    # hatomcat.mon  [-i monitor_interval] [-r retry_times] 
    . $TKIT_SCRIPT_DIR/hatomcat.mon -i $MONITOR_INTERVAL -r $RETRY_TIMES
    ;;
stop)
    stop_server
    ;;
*)
    echo "Invalid Argument"
    ;;
esac
exit $exit_code
